# remirepo/fedora spec file for php-clue-socks-react
#
# Copyright (c) 2020 Remi Collet, Shawn Iwinski
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     clue
%global github_name      reactphp-socks
%global github_version   1.2.0
%global github_commit    d2d87448e8990ab18f5c72cda0195cf1c506baf8

%global composer_vendor  clue
%global composer_project socks-react


# Build using "--without tests" to disable tests
%bcond_without tests

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Async SOCKS proxy connector client and server implementation

License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}

# GitHub export does not include tests
# Run php-clue-socks-react-get-source.sh to create full source
Source0:       %{name}-%{github_version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Tests
%if %{with tests}
BuildRequires: php(language) >= 5.3
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(react/promise)    >= 2.1    with php-composer(react/promise)     < 3)
BuildRequires: (php-composer(react/socket)     >= 1.1    with php-composer(react/socket)      < 2)
## composer.json
#        "phpunit/phpunit": "^9.3 || ^5.7 || ^4.8.35",
#        "react/event-loop": "^1.0 || ^0.5 || ^0.4 || ^0.3",
#        "react/http": "^1.0",
#        "clue/connection-manager-extra": "^1.0 || ^0.7",
#        "clue/block-react": "^1.1"
# ignore react/http and clue/connection-manager-extra only used in examples
BuildRequires: (php-composer(react/event-loop) >= 1.0    with php-composer(react/event-loop)  < 2)
BuildRequires: (php-composer(clue/block-react) >= 1.1    with php-composer(clue/block-react)  < 2)
%else
BuildRequires: php-react-promise               >= 2.1
BuildRequires: php-react-socket                >= 1.1
BuildRequires: php-react-event-loop            >= 1.0
BuildRequires: php-clue-block-react            >= 1.1
%endif
%if 0%{?fedora} >= 32 || 0%{?rhel} >= 9
%global phpunit %{_bindir}/phpunit9
BuildRequires: phpunit9 >= 9.3
%else
%global phpunit %{_bindir}/phpunit
BuildRequires: php-phpunit-PHPUnit >= 4.8
%endif
## phpcompatinfo (computed from version 1.2.0)
BuildRequires: php-reflection
BuildRequires: php-pcre
BuildRequires: php-sockets
BuildRequires: php-spl
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# composer.json
#        "php": ">=5.3",
#        "react/promise": "^2.1 || ^1.2",
#        "react/socket": "^1.1"
Requires:      php(language) >= 5.3
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(react/promise)    >= 2.1    with php-composer(react/promise)     < 3)
Requires:      (php-composer(react/socket)     >= 1.1    with php-composer(react/socket)      < 2)
%else
Requires:      php-react-promise               >= 2.1
Requires:      php-react-socket                >= 1.1
%endif
# phpcompatinfo (computed from version 1.2.0)
Requires:      php-reflection
Requires:      php-pcre
Requires:      php-sockets
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Async SOCKS proxy connector client and server implementation,
tunnel any TCP/IP-based protocol through a SOCKS5 or SOCKS4(a)
proxy server, built on top of ReactPHP.

Autoloader: %{phpdir}/Clue/React/Socks/autoload.php

[1] http://reactphp.org/


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create autoloader
cat <<'AUTOLOAD' | tee src/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Clue\\React\\Socks\\', __DIR__);

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/React/Promise/autoload.php',
    '%{phpdir}/React/Socket/autoload.php',
));
AUTOLOAD


%install
mkdir   -p %{buildroot}%{phpdir}/Clue/React
cp -rp src %{buildroot}%{phpdir}/Clue/React/Socks


%check
%if %{with tests}
: Mock Composer autoloader
mkdir vendor
cat <<'AUTOLOAD' | tee vendor/autoload.php
<?php
require_once '%{buildroot}%{phpdir}/Clue/React/Socks/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Clue\\Tests\\React\\Socks\\', dirname(__DIR__).'/tests');
\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/React/EventLoop/autoload.php',
    '%{phpdir}/Clue/React/Block/autoload.php',
));
AUTOLOAD

FILTER="--filter '^((?!(testConnectionWithIpv6ViaSocks4Fails)).)*$'"

: Upstream tests
RETURN_CODE=0
for CMDARG in "php %{phpunit}" "php72 %{_bindir}/phpunit" php73 php74 php80; do
    if which $CMDARG; then
        set $CMDARG
        $1 ${2:-%{_bindir}/phpunit9} --verbose \
            $FILTER || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Clue/React/Socks


%changelog
* Wed Nov  4 2020 Remi Collet <remi@remirepo.net> - 1.2.0-1
- Initial package
